/**
 * @file content script for heatmap
 * @since 2018-10-10
 */

/* global chrome */

const HolmesHeatMapUtils = Object.freeze({
    UserAgentChangeEventName: 'HolmesHeatMapUserAgentChange',

    UserAgentChangedEventName: 'HolmesHeatMapUserAgentChanged',

    getAllowedOrigin() {
        const href = window.location.href;

        const protocol = HolmesHeatMapUtils.getUrlProtocol(href);

        return protocol != null ? protocol + '//tongji.baidu.com' : protocol;
    },

    getUrlProtocol(url) {
        const match = url.match(/^(https?:)\/\//);
        return match ? match[1] : null;
    }
});


const HolmesHeatMap = Object.freeze({
    eventListener(event) {
        const {origin, data} = event;
        const {type, msg} = data;

        if (// origin === HolmesHeatMapUtils.getAllowedOrigin()
            type === HolmesHeatMapUtils.UserAgentChangeEventName
            && msg !== '') {
            HolmesHeatMap.updateUserAgent({
                type: 'HEATMAP_SETUA',
                uaType: msg
            }, HolmesHeatMap.updateUserAgentDone)
        }
    },

    updateUserAgent(message, callback) {
        if (message.type === 'HEATMAP_SETUA') {
            chrome.runtime.sendMessage({uaType: message.uaType, type: message.type}, callback);
        }
    },

    updateUserAgentDone() {
        window.postMessage({type: HolmesHeatMapUtils.UserAgentChangedEventName, msg: 'Hello, I am from content.'}, '*');
    },

    initDetectDom() {
        let element = document.createElement('div');
        element.id = 'detect-holmes-debugger-1541053963293';
        document.body.appendChild(element);
    }
});

// 注册插件检测 dom 元素
HolmesHeatMap.initDetectDom();

// 注册于 page 通信
window.addEventListener('message', HolmesHeatMap.eventListener, false);
